#ifndef WCALC_ISCONST
#define WCALC_ISCONST

int isconst(const char *str);

#endif
